@@ -69,10 +69,13 @@ def invoke_get_request(url: str, headers: dict, on_success=None, on_backoff=None
 
 @lru_cache(maxsize=None)
 def get_dynamic_values_from_files(value: str, directory: str) -> list:
+    if '|' not in value:
+        return [value]
+
     parameter_file = value.split("|")[0]
     parameter_file = "{}/{}".format(
         directory, parameter_file
-    )
+    ).strip()
 
     # Get array if a globbing pattern is used (ex. "*.json")
     parameter_files = glob.glob(parameter_file)
